@@ -1,16 +1,18 @@
 """Model probability plots"""
 
-from ..storage import History
 import matplotlib as mpl
 import matplotlib.axes
 import matplotlib.pyplot as plt
 
+from ..storage import History
+
 
 def plot_model_probabilities(
-        history: History,
-        rotation: int = 0,
-        title: str = "Model probabilities",
-        ax: mpl.axes.Axes = None):
+    history: History,
+    rotation: int = 0,
+    title: str = "Model probabilities",
+    ax: mpl.axes.Axes = None,
+):
     """
     Plot the probabilities of models over time.
 
